import time
import hashlib


class AccToken:
    def __init__(self, user_nonce, user_key):
        self.user_nonce = user_nonce
        self.user_key = user_key

    def generate(self):
        timestamp = int(time.time())
        hash = hashlib.sha256()
        hash.update(f"{timestamp}{self.user_key}".encode())
        return f"{self.user_nonce}:{timestamp}:{hash.hexdigest()}"



from .token import AccToken
import requests


class AccClientFactory:
    def __init__(self, user_nonce, user_key):
        self._token = AccToken(user_nonce, user_key)

    def create(self, address, username, password, client_name="Python client"):
        response = _query("POST", _url(address, "login"), json={
            "authorizationToken": self._token.generate(),
            "username": username,
            "password": password,
            "clientName": client_name
        })
        return AccClient(address, response['session'])


class AccClient:
    def __init__(self, address, session):
        self.address = address
        self.session = session

    def get_cameras(self, verbosity="LOW"):
        response = _query("GET", _url(self.address, "cameras"), {
            "verbosity": verbosity,
            "session": self.session
        })
        return response["cameras"]


def _url(address, path):
    return f"{address}/mt/api/rest/v1/{path}"


def _query(method, url, params=None, json=None):
    response = requests.request(
        method, url, params=params, json=json, verify=False)
    response.raise_for_status()
    response_data = response.json()
    if (response_data["status"] != "success"):
        raise Exception(response_data["status"])
    return response_data["result"]



from setuptools import setup, find_packages

VERSION = '0.0.3' 
DESCRIPTION = 'Avigilon Control Center API for Python'

with open("README.md", "r", encoding="utf-8") as fh:
    LONG_DESCRIPTION = fh.read()

setup(
        name="accapi", 
        version=VERSION,
        author="Jakub Bartkowiak",
        author_email="gralinpl@gmail.com",
        project_urls={
            "Source": "https://github.com/gralin/acc-api-python",
        },
        description=DESCRIPTION,
        long_description=LONG_DESCRIPTION,
        long_description_content_type="text/markdown",
        packages=find_packages(),
        install_requires=[],      
        keywords=['python', 'acc', 'avigilon'],
        classifiers= [
            "Programming Language :: Python :: 3",
            "License :: OSI Approved :: MIT License",
            "Operating System :: OS Independent",
        ]
)